@@ -1,9 +1,9 @@
 use crate::storage::Storage;
-use crate::Status;
+use crate::{LogLevel, Status};
 use anyhow::{anyhow, Context, Result};
 use chrono::{DateTime, Utc};
 use colored::*;
-use log::info;
+use log::{debug, error, info, trace, warn, Log};
 use serde::{Deserialize, Serialize};
 use std::fmt::{Debug, Display, Formatter};
 use std::path::{Path, PathBuf};
@@ -26,6 +26,10 @@ pub struct Command {
     user: String,
     machine: String,
     os: String,
+    #[serde(skip)]
+    success_log_level: LogLevel,
+    #[serde(skip)]
+    fail_log_level: LogLevel,
 }
 
 // associated functions
@@ -232,6 +236,16 @@ impl Command {
         self
     }
 
+    pub fn success_log_level(&mut self, level: LogLevel) -> &mut Command {
+        self.success_log_level = level;
+        self
+    }
+
+    pub fn fail_log_level(&mut self, level: LogLevel) -> &mut Command {
+        self.fail_log_level = level;
+        self
+    }
+
     fn output(&mut self) -> Result<std::process::Output> {
         // TODO: restore current_dir is it changed
         match self.timeout {
@@ -302,9 +316,11 @@ impl Command {
                 user: whoami::username(),
                 machine: whoami::hostname(),
                 os: whoami::distro(),
+                success_log_level: self.success_log_level,
+                fail_log_level: self.fail_log_level,
             };
             Storage::add(&command)?;
-            info!("{}", &command);
+            command.log();
             Ok(command)
         } else {
             Err(anyhow!(
@@ -321,7 +337,42 @@ impl Command {
     pub fn set_stderr(&mut self, stderr: Vec<u8>) {
         self.stderr = stderr
     }
+
+    fn log(&self) {
+        match self.exit_code() {
+            Some(exit_code) => {
+                if exit_code == 0 {
+                    Command::log_msg(&format!("{}", &self), self.success_log_level);
+                } else {
+                    Command::log_msg(&format!("{}", &self), self.fail_log_level);
+                }
+            }
+            None => {}
+        }
+    }
+
+    fn log_msg(msg: &str, level: LogLevel) {
+        match level {
+            LogLevel::Off => {}
+            LogLevel::Trace => {
+                trace!("{}", msg);
+            }
+            LogLevel::Debug => {
+                debug!("{}", msg);
+            }
+            LogLevel::Info => {
+                info!("{}", msg);
+            }
+            LogLevel::Warn => {
+                warn!("{}", msg);
+            }
+            LogLevel::Error => {
+                error!("{}", msg);
+            }
+        }
+    }
 }
+
 impl Display for Command {
     fn fmt(&self, f: &mut Formatter) -> std::fmt::Result {
         let duration = self.duration_string();
